Module error

Module error 

Error type carrying a position in the user’s source expression.

Structs

Error
Span
Byte range into the display source of a compiled program.

Enums

ErrorKind
Broad class of a failure. NotYet and Language are deliberately distinct: the former is a promise, the latter is a property of J/APL.

Type Aliases

Result