pub enum DepthSign {
Unsigned,
Signed,
}Expand description
What monadic ≡ answers for an array whose items differ in depth.
Both lines answer with the depth. The other one negates it where the array is not uniform: where two items of it, at any level, differ in depth or in shape.
Variants