pub enum DfnResult {
LastSentence,
FirstNonAssignment,
}Expand description
Which sentence of a dfn body is its result.
libjay’s block model — the value of the last sentence — is what both languages’ sequences do. The other reading stops at the first sentence that is not an assignment and answers with its value.
Variants