intern

Function intern 

pub fn intern(name: &str) -> Id
The id of name, adding it to the table if it is new.

Panics only if the table is exhausted, which needs four billion distinct names in one process.