ScalarMonad

Enum ScalarMonad 

pub enum ScalarMonad {
Show 21 variants Conj, Neg, Signum, Recip, Sqrt, Exp, Abs, Floor, Ceil, Not, OneMinus, Inc, Dec, Double, Halve, Square, Ln, Pi, Factorial, Imaginary, Polar,
}
Elementwise monadic operations (cell rank 0).

Variants



Conj

Identity on reals (J +, APL +).



Neg



Signum



Recip



Sqrt



Exp



Abs



Floor



Ceil



Not

APL ~: logical negation; the argument must be 0 or 1.



OneMinus

J -.: 1 - y on any number (a superset of logical negation).



Inc

y + 1 (J >:).



Dec

y - 1 (J <:).



Double

y + y (J +:).



Halve

y % 2 (J -:); always float.



Square

y * y (J *:).



Ln

Natural logarithm (J ^., APL ); always float.



Pi

pi * y (J/APL monadic o. / ); always float.



Factorial

! y: factorial, i.e. the gamma function at y+1. Always float, as in J; a negative integer is a pole and yields a signed infinity.



Imaginary

J j. y: 0j1 * y. Always complex.



Polar

J r. y: ^ 0j1 * y, the unit complex at angle y. Always complex.